use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib examples lib script t xt ) );
__DATA__
irc
Matthijs
van
Duin
xmath
and
cPanel
Inc
Karen
Etheridge
ether
Leon
Timmermans
fawaka
Florian
Ragwitz
rafl
Reini
Urban
rurban
gfx
gfuji
Dagfinn
Ilmari
Mannsåker
ilmari
Aristotle
Pagaltzis
pagaltzis
Mash
jmash
lib
Sub
Name
